@@ -31,22 +31,12 @@ class Resource(BaseModel):
 T = typing.TypeVar("T", bound=Resource)
 
 
-class Query(typing.Generic[T]):
-    def __init__(self, cls: typing.Type[T]) -> None:
-        self.cls = cls
-
-    def all(self) -> typing.List[T]:
-        return DEFAULT_STORAGE.all(cls=self.cls)
-
-
-def query(cls: typing.Type[T]) -> Query[T]:
-    return Query(cls)
-
-
-def Related(to: typing.Union[typing.Type[T], str]) -> str:
+def Related(
+    to: typing.Union[typing.Type[T], str], title: str = None, description: str = None
+) -> str:
     if inspect.isclass(to):
         to = to.__name__
-    return Field(relatedTo=to)
+    return Field(relatedTo=to, title=title, description=description)
 
 
 def Name() -> str:  # type: ignore
@@ -57,11 +47,6 @@ def UserEmail() -> str:  # type: ignore
     pass
 
 
-class Context(metaclass=ModelMeta):
-    def __init__(self, **data: typing.Any) -> None:
-        setattr(self, "__dict__", data)
-
-
 _ALL_RESOURCES: typing.List[Resource] = []
 
 
